==> seedsui-react-5.8.44.tgz: package/lib/Loading/show.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import locale from "./../locale";

// 显示Loading
// eslint-disable-next-line
export default function (props) {
  var _ref = _objectSpread(_objectSpread({}, (this === null || this === void 0 ? void 0 : this.defaultProps) || {}), props || {}),
    id = _ref.id,
    maskProps = _ref.maskProps,
    captionProps = _ref.captionProps,
    className = _ref.className,
    style = _ref.style,
    content = _ref.content,
    onVisibleChange = _ref.onVisibleChange;
  // 渲染
  function render() {
    var loadingId = id || '__SeedsUI_loading_el__';
    // 如果没生成成功, 则强制生成
    var mask = document.getElementById(loadingId);
    if (!mask) {
      mask = document.createElement('div');
      mask.innerHTML = "<div class=\"loading-container\">\n          <div class=\"loading-floating-icon\">\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n          </div>\n          <div class=\"loading-floating-caption loading-content\"></div>\n        </div>"
      // 添加到dom上
      ;
      (document.getElementById('root') || document.body).appendChild(mask);
    }

    // 更新mask
    mask.setAttribute('class', "loading-mask mask active".concat(maskProps !== null && maskProps !== void 0 && maskProps.className ? ' ' + (maskProps === null || maskProps === void 0 ? void 0 : maskProps.className) : ''));
    mask.setAttribute('id', loadingId);
    mask.setAttribute('style', '');
    for (var key in (maskProps === null || maskProps === void 0 ? void 0 : maskProps.style) || {}) {
      mask.style[key] = maskProps === null || maskProps === void 0 ? void 0 : maskProps.style[key];
    }

    // 更新container
    var container = mask.querySelector('.loading-container');
    if (container) {
      container === null || container === void 0 || container.setAttribute('class', "loading-container loading-floating animated".concat(className ? ' ' + className : ''));
      container === null || container === void 0 || container.setAttribute('style', '');
      for (var _key in style || {}) {
        container.style[_key] = style[_key];
      }
    }
    var caption = (captionProps === null || captionProps === void 0 ? void 0 : captionProps.caption) || content;
    caption = typeof caption === 'string' ? caption : locale('加载中...', 'SeedsUI_loading');
    mask.querySelector('.loading-content').innerHTML = caption;

    // 显示
    mask.classList.add('active');
    if (typeof onVisibleChange === 'function') {
      onVisibleChange(true);
    }
    return mask;
  }
  return render();
}

==> seedsui-react-5.8.96.tgz: package/lib/Loading/show.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import locale from "./../locale";

// 显示Loading
// eslint-disable-next-line
export default function (props) {
  var _ref = _objectSpread(_objectSpread({}, (this === null || this === void 0 ? void 0 : this.defaultProps) || {}), props || {}),
    id = _ref.id,
    maskProps = _ref.maskProps,
    captionProps = _ref.captionProps,
    className = _ref.className,
    style = _ref.style,
    content = _ref.content,
    onVisibleChange = _ref.onVisibleChange;

  // 渲染
  function render() {
    var loadingId = id || '__SeedsUI_loading_mask__';
    var mask = document.getElementById(loadingId);

    // 如果没生成成功, 则强制生成
    if (!mask) {
      mask = document.createElement('div');
      mask.innerHTML = "<div class=\"loading-container\">\n          <div class=\"loading-floating-icon\">\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n            <div class=\"loading-floating-blade\"></div>\n          </div>\n          <div class=\"loading-floating-caption loading-content\"></div>\n        </div>";

      // 添加到dom上
      var root = document.getElementById('root') || document.body;
      root.appendChild(mask);
    }

    // 更新mask
    mask.setAttribute('class', "loading-mask mask active".concat(maskProps !== null && maskProps !== void 0 && maskProps.className ? ' ' + (maskProps === null || maskProps === void 0 ? void 0 : maskProps.className) : ''));
    mask.setAttribute('id', loadingId);
    mask.setAttribute('style', '');
    for (var key in (maskProps === null || maskProps === void 0 ? void 0 : maskProps.style) || {}) {
      mask.style[key] = maskProps === null || maskProps === void 0 ? void 0 : maskProps.style[key];
    }

    // 更新container
    var container = mask.querySelector('.loading-container');
    if (container) {
      container === null || container === void 0 || container.setAttribute('class', "loading-container loading-floating animated".concat(className ? ' ' + className : ''));
      container === null || container === void 0 || container.setAttribute('style', '');
      for (var _key in style || {}) {
        container.style[_key] = style[_key];
      }
    }
    var caption = (captionProps === null || captionProps === void 0 ? void 0 : captionProps.caption) || content;
    caption = typeof caption === 'string' ? caption : locale('加载中...', 'SeedsUI_loading');
    mask.querySelector('.loading-content').innerHTML = caption;

    // 显示
    mask.classList.add('active');
    if (typeof onVisibleChange === 'function') {
      onVisibleChange(true);
    }
    return mask;
  }
  return render();
}
